<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dealer Management Dashboard</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body class="p-5">
    <div class="container">
        <!-- User Info and Logout -->
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                @if(auth()->user()->role === 'Admin')
                <a href="{{ route('leads') }}" class="custom-btn align-items-left btn" 
                   style="background-color: #74544c; color: white; padding: 10px 20px; border-radius: 5px; text-decoration: none; display: inline-block; border: none;">
                   View Leads
                </a>
            @endif

            </div>
            <div class="d-flex align-items-center">
                <div class="text-end me-3" style="font-size: 14px;">
                    <p class="mb-0"><strong>{{ auth()->user()->name }}</strong></p>
                    <p class="mb-0 text-muted" style="font-size: 12px;">{{ auth()->user()->email }}</p>
                </div>
                <form action="{{ route('logout') }}" method="POST">
                    @csrf
                    <button type="submit" class="btn btn-danger btn-sm">Logout</button>
                </form>
            </div>
        </div>

        <!-- Dealer Management -->
        <h4>Dealer Management</h4>

        <div class="row mb-3">
            <div class="col-12">
                <div class="d-flex align-items-center justify-content-between">
                    <div class="d-flex align-items-center flex-grow-1">
                        <input type="text" id="search" class="form-control me-2" placeholder="Search Dealers..." style="max-width: 300px;">
                        <h6 class="mb-0" style="margin-left: 50px;">
                            <strong>📊 Total Dealers : <span id="totalCount"></span></strong>
                        </h6>
                    </div>
                    @if(auth()->user()->role === 'Admin')
                        <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#dealerModal">Create Dealer</button>
                    @endif
                </div>
            </div>
        </div>
        

        <!-- Dealer Table -->
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Pincode</th>
                    <th>Email</th>
                    <th>Mobile</th>
                    <th>Role</th>
                    <th>Add Pincode</th>
                    <th>View Lead</th>
                </tr>
            </thead>
            <tbody id="dealerTable"></tbody>
        </table>
        <div id="pagination"></div>

        <!-- Toast Notification -->
        <div id="toast-container" class="position-fixed top-0 end-0 p-3" style="z-index: 1050;">
            <div id="successToast" class="toast bg-success text-white align-items-center" role="alert" aria-live="polite" aria-atomic="true">
                <div class="d-flex">
                    <div class="toast-body" id="toastMessage"></div>
                    <button type="button" class="btn-close btn-close-white me-2 m-auto" data-bs-dismiss="toast"></button>
                </div>
            </div>
        </div>

        <!-- Create Dealer Modal -->
        <div class="modal fade" id="dealerModal" tabindex="-1">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Create Dealer</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <form id="dealerForm">
                            @csrf
                            <div class="mb-3">
                                <label>Name</label>
                                <input type="text" name="name" class="form-control" required>
                                <span class="text-danger error-name"></span>
                            </div>
                            <div class="mb-3">
                                <label>Email</label>
                                <input type="email" name="email" class="form-control" required>
                                <span class="text-danger error-email"></span>
                            </div>
                            <div class="mb-3">
                                <label>Password</label>
                                <input type="password" name="password" class="form-control" required>
                                <span class="text-danger error-password"></span>
                            </div>
                            <div class="mb-3">
                                <label>Mobile</label>
                                <input type="text" name="mobile" class="form-control only-numbers" maxlength="10" required>
                                <span class="text-danger error-mobile"></span>
                            </div>
                            <div class="mb-3">
                                <label>Pincode</label>
                                <input type="text" name="pincode" class="form-control only-numbers" maxlength="6" required>
                                <span class="text-danger error-pincode"></span>
                            </div>
                            <button type="submit" class="btn btn-success">Save Dealer</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        <!-- Add Pincode Modal -->
        <div class="modal fade" id="addPincodeModal" tabindex="-1" aria-labelledby="modalTitle" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="modalTitle">Add Pincode</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" id="userId">
                        <div class="mb-3">
                            <label for="pincode" class="form-label">Enter Pincode</label>
                            <input type="text" id="newpincode" name="newpincode" class="form-control only-numbers" maxlength="6">
                            <span class="text-danger error-pincode"></span>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                        <button type="button" class="btn btn-primary" id="savePincode">Save</button>
                    </div>
                </div>
            </div>
        </div>

    </div>

    <script>
        function fetchDealers(page = 1, search = '') {
            $.ajax({
                url: "{{ route('dealers.index') }}",
                type: "GET",
                data: { search: search, page: page },
                success: function (response) {

                    let rows = response.data.map(dealer => {
                    let pincodeList = dealer.pincode.map(pin => pin.pincode).join(", "); 
                   
                    document.getElementById("totalCount").textContent = response.totalCount ?? 0;

                        return `
                            <tr>
                                <td>${dealer.name}</td>
                                <td>${pincodeList}</td>  <!-- Show multiple pincodes -->
                                <td>${dealer.email}</td>
                                <td>${dealer.mobile}</td>
                                <td>${dealer.role}</td>
                                <td>
                                    <button class="btn btn-sm btn-primary openPincodeModal" data-id="${dealer.id}"  style="background-color: #afabaa; color: white; border: none;">
                                        Add Pincode
                                    </button>
                                </td>
                                <td><a href="{{ url('dealerLeadList') }}/${dealer.id}" class="btn btn-sm"  style="background-color: #afabaa" >👁️</a></td>

                            </tr>`;
                    }).join('');

            
                    $('#dealerTable').html(rows);

                    let pagination = `
                        <nav>
                            <ul class="pagination justify-content-center">
                                ${response.prev_page_url ? `<li class="page-item"><a class="page-link" href="#" onclick="fetchDealers(${response.current_page - 1})">Previous</a></li>` : ''}
                                <li class="page-item disabled"><a class="page-link">Page ${response.current_page} of ${response.last_page}</a></li>
                                ${response.next_page_url ? `<li class="page-item"><a class="page-link" href="#" onclick="fetchDealers(${response.current_page + 1})">Next</a></li>` : ''}
                            </ul>
                        </nav>`;
                    $('#pagination').html(pagination);
                }
            });
        }

        $(document).ready(function () {
            fetchDealers();
            $('#search').on('keyup', function () { fetchDealers(1, $(this).val()); });
            $('.only-numbers').on('input', function () { this.value = this.value.replace(/[^0-9]/g, ''); });

            $('#dealerForm').submit(function (e) {
                e.preventDefault();
                $('.text-danger').text('');
                $.ajax({
                    url: "{{ route('dealer.store') }}",
                    type: "POST",
                    data: $(this).serialize(),
                    success: function () {
                        showSuccessToast('Dealer created successfully!');
                        $('#dealerModal').modal('hide');
                        $('#dealerForm')[0].reset(); 
                        fetchDealers();
                    },
                    error: function (xhr) {
                        if (xhr.status === 422) {
                            let errors = xhr.responseJSON.errors;
                            for (let key in errors) {
                                $(`.error-${key}`).text(errors[key][0]);
                            }
                        }
                    }
                });
            });
        });

        function showSuccessToast(message) {
            $('#toastMessage').text(message);
            new bootstrap.Toast(document.getElementById('successToast')).show();
        }
        
        $(document).ready(function () {
            $(document).on("click", ".openPincodeModal", function () {
                let userId = $(this).data("id");
                $("#userId").val(userId);
                $("#newpincode").val('');
                $("#pincodeError").addClass("d-none");
                $(".text-danger").text("");
                $("#addPincodeModal").modal("show");
            });

        $("#savePincode").click(function () {
            let userId = $("#userId").val();
            let newpincode = $("#newpincode").val();      

            if (!newpincode || newpincode.length !== 6 || isNaN(newpincode)) {
                $("#pincodeError").text("Pincode must be exactly 6 digits").removeClass("d-none");
                return;
            }

            $.ajax({
                url: "{{ route('dealers.addPincode') }}",
                type: "POST",
                data: {
                    dealer_id: userId,
                    pincode: newpincode,
                    _token: "{{ csrf_token() }}"
                },
                success: function (response) {
                    showSuccessToast("Pincode added successfully!");
                    $("#addPincodeModal").modal("hide");
                    fetchDealers();
                },
                    error: function (xhr) {
                        let response = xhr.responseJSON;
                    
                    if (typeof response.errors === "string") {
                        $(".error-pincode").text(response.errors).removeClass("d-none");
                    } else {
                        $(".text-danger").text("");
                        for (let key in response.errors) {
                            $(`.error-${key}`).text(response.errors[key][0]).removeClass("d-none");
                        }
                    }
                }
            });
        });
    });
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>