<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Lead Dashboard</title>
    
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    
    <!-- jQuery -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <style>
        body {
            background-color: #f8f9fa;
            font-family: Arial, sans-serif;
        }
        .container {
            margin-top: 30px;
            background: #fff;
            padding: 25px;
            border-radius: 10px;
            box-shadow: 0px 0px 15px rgba(0, 0, 0, 0.2); /* Stronger shadow */
        }
        .search-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .search-container input {
            width: 300px;
        }
        .table-responsive {
            max-height: 900px;
            overflow-y: auto;
        }
        table {
            margin-top: 20px;
        }
        th {
            position: sticky;
            top: 0;
            background: #343a40;
            color: white;
            z-index: 2;
        }
        th, td {
            text-align: center;
            vertical-align: middle;
        }
        .pagination-btns {
            display: flex;
            justify-content: center;
            margin-top: 15px;
        }
    </style>
</head>
<body>


        

<div class="container">
    @if (Auth::user()->role == 'Admin')
    <a href="{{ route('dashboard') }}" >Back</a>

    @endif
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h4>Lead Dashboard</h4>
        <h6 >
            <strong>Dealer Details : <span id="dealerName"></span> [ <span id="pincodeData"></span> ]</strong>
        </h6>
   

        <div class="d-flex align-items-center">
            <div class="text-end me-3" style="font-size: 14px;">
                <p class="mb-0"><strong>{{ ucfirst(auth()->user()->name) }}</strong> [{{ auth()->user()->role }}]</p>
                <p class="mb-0 text-muted" style="font-size: 12px;">{{ auth()->user()->email }}</p>
            </div>
            <form action="{{ route('logout') }}" method="POST">
                @csrf
                <button type="submit" class="btn btn-danger btn-sm">Logout</button>
            </form>
        </div>

    </div>

    <!-- Search Bar -->
    <div class="search-container mb-3">
        <input type="text" id="search" class="form-control form-control-sm" placeholder="Search Leads...">
        <h6 class="mb-0">
            <strong>📊 Total Leads: <span id="totalCount"></span></strong>
        </h6>
        <h6 class="mb-0 text-warning">
            <strong>⏳ Pending: <span id="pending_lead"></span></strong>
        </h6>
        <h6 class="mb-0 text-primary">
            <strong>🔄 In Progress: <span id="inProgress_lead"></span></strong>
        </h6>
        <h6 class="mb-0 text-success">
            <strong>✅ Approved: <span id="approved_lead"></span></strong>
        </h6>
    </div>

    <!-- Leads Table -->
    <div class="table-responsive">
        <table class="table table-bordered table-striped">
            <thead class="table-dark">
                <tr>
                    <th>Name</th>
                    <th>Contact</th>
                    <th>Address</th>
                    <th>Date of Birth</th>
                    <th>Employment</th>
                    <th>Income</th>
                    <th>Vehicle Type</th>
                    <th>Vehicle Preference</th>
                    <th>Status</th>
                    <th>Created Date</th>
                    @if(auth()->user()->role === 'Admin')
                        <th>Assigned</th>
                    @else
                        <th>Action</th>
                    @endif                  
                    <th>View More</th>
                </tr>
            </thead>
            <tbody id="userLeadsTable"></tbody>
        </table>
    </div>

    <!-- Pagination -->
    <div class="pagination-btns">
        <button id="prevPage" class="btn btn-secondary btn-sm" disabled>Previous</button>
        <span id="currentPage" class="mx-3">1</span>
        <button id="nextPage" class="btn btn-secondary btn-sm" disabled>Next</button>
    </div>

   <!-- Lead Details Modal -->
    <div class="modal fade" id="viewLeadModal" tabindex="-1" aria-labelledby="modalTitle" aria-hidden="true">
        <div class="modal-dialog modal-lg"> <!-- Enlarged modal size -->
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalTitle">Lead Details</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body" style="max-height: 500px; overflow-y: auto;"> 
                    <div class="row">
                        <div class="col-md-6">
                            <p><strong>Lead Created Date:</strong> <span id="modalCreatedDate"></span></p>
                            <p><strong>Full Name:</strong> <span id="modalFullName"></span></p>
                            <p><strong>DOB:</strong> <span id="modalDOB"></span></p>
                            <p><strong>Phone:</strong> <span id="modalPhone"></span></p>
                            <p><strong>Email:</strong> <span id="modalEmail"></span></p>
                            <p><strong>Address:</strong> <span id="modalAddress"></span></p>
                            <p><strong>Zip Code:</strong> <span id="modalZipCode"></span></p>
                            <p><strong>Employment Name (Company):</strong> <span id="modalEmployerName"></span></p>
                            <p><strong>Employment Status:</strong> <span id="modalEmploymentStatus"></span></p>
                            <p><strong>Job Title:</strong> <span id="modalJobTitle"></span></p>
                            <p><strong>Employment Duration:</strong> <span id="modalEmploymentDuration"></span></p>
                        </div>
                        
                        <div class="col-md-6">
                            <p><strong>Monthly Income:</strong> <span id="modalIncome"></span></p>
                            <p><strong>Work Phone:</strong> <span id="modalWorkPhone"></span></p>
                            <p><strong>Housing Status:</strong> <span id="modalHousingStatus"></span></p>
                            <p><strong>Monthly Payment:</strong> <span id="modalMonthlyPayment"></span></p>
                            <p><strong>Residence Duration:</strong> <span id="modalResidenceDuration"></span></p>
                            <p><strong>Bankruptcy History:</strong> <span id="modalBankruptcyHistory"></span></p>
                            <p><strong>Co-Signer:</strong> <span id="modalCoSigner"></span></p>
                            <p><strong>Social Security Number (SSN):</strong> <span id="modalSSN"></span></p>
                            <p><strong>Credit Check Consent:</strong> <span id="modalCreditCheck"></span></p>
                            <p><strong>Vehicle Type:</strong> <span id="modalVehicle"></span></p>
                            <p><strong>Vehicle Preference:</strong> <span id="modalPreference"></span></p>
                            <p><strong>Status:</strong> <span id="modalStatus"></span></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>


</div>

<script>
    let currentPage = 1;
    let typingTimer;
    let doneTypingInterval = 500;  // Delay for search

    function fetchUserLeads() {
        let searchQuery = $("#search").val();

        let pathParts = window.location.pathname.split("/");
        let dealerId = pathParts[pathParts.length - 1]; 

        $.ajax({
            url: `/getdealerLead`, 
            type: "GET",
            data: { id: dealerId,page: currentPage, search: searchQuery },
            success: function(response) {
                let rows = "";
                let users = response.users; 

                if (response.data.length === 0) {
                    rows = `<tr><td colspan="12" class="text-danger fw-bold small">Not Found</td></tr>`;
                } 

                $.each(response.data, function(index, lead) {
                    let address = `${lead.street}, ${lead.city}, ${lead.state} - ${lead.zip_code}`;

                    document.getElementById("totalCount").textContent = response.total_leads ?? 0;

                    document.getElementById("pending_lead").textContent = response.leads_per_status.pending ?? 0; 

                    document.getElementById("inProgress_lead").textContent = response.leads_per_status.inProgress ?? 0;

                    document.getElementById("approved_lead").textContent = response.leads_per_status.approved ?? 0;

                    document.getElementById("dealerName").textContent = response.dealerName.charAt(0).toUpperCase() + response.dealerName.slice(1);

                    document.getElementById("pincodeData").textContent = response.dealerPincode.map(item => item.pincode).join(", "); 
                
                    let createdDate = new Date(lead.created_at).toLocaleString('en-US', {
                    year: 'numeric', month: 'long', day: 'numeric',
                    hour: '2-digit', minute: '2-digit', second: '2-digit'
                    });

                    rows += `<tr>
                        <td>${lead.full_name}</td>
                        <td>${lead.phone_number}</td>
                        <td>${lead.street}, ${lead.city}, ${lead.state} - ${lead.zip_code}</td>
                        <td>${lead.date_of_birth}</td>
                        <td>${lead.employment_status}</td>
                        <td>${lead.monthly_income}</td>
                        <td>${lead.vehicle_type}</td>
                        <td>${lead.vehicle_preference}</td>

                        <td style="color: ${lead.status === 'pending' ? 'white' : lead.status === 'approved' ? 'white' : 'black'};
                                background-color: ${lead.status === 'pending' ? '#b8cac6' : lead.status === 'approved' ? 'green' : 'yellow'};">
                            ${lead.status.charAt(0).toUpperCase() + lead.status.slice(1).toLowerCase()}
                        </td>
                        <td>${createdDate}</td>`;

                    if ('{{ auth()->user()->role }}' === 'Admin') {
                            rows += `<td>
                                <select class="form-select form-select-sm assign-user" data-id="${lead.id}">
                                    <option value="">Select User</option>`;
                                users.forEach(user => {
                                    let selected = lead.assigned_user_id == user.id ? "selected" : "";

                                    let pincodes = user.pincode.map(pin => pin.pincode).join(', ');

                                    rows += `<option value="${user.id}" ${selected}>${user.name} (${pincodes})</option>`;
                                });
                            rows += `</select></td>`;

                    } else {
                        rows += `<td>
                                    <select class="form-select form-select-sm status-change" data-id="${lead.id}">
                                        <option value="pending" ${lead.status == 'pending' ? 'selected' : ''}>Pending</option>
                                        <option value="approved" ${lead.status == 'approved' ? 'selected' : ''}>Approved</option>
                                        <option value="inProgress" ${lead.status == 'inProgress' ? 'selected' : ''}>In Progress</option>
                                    </select>
                                </td>`;
                    }

                    rows += `<td>
                    <button class="btn btn btn-sm view-details" style="background-color: #afabaa" 
                        data-lead='${JSON.stringify(lead)}'>
                        👁️
                    </button>
                    </td>`;
                    
                    rows += `</tr>`;

                });

                $("#userLeadsTable").html(rows);

                // Update Pagination
                $("#currentPage").text(response.pagination.current_page);
                currentPage = response.pagination.current_page;
                $("#prevPage").prop("disabled", !response.pagination.prev_page_url);
                $("#nextPage").prop("disabled", !response.pagination.next_page_url);
            }
        });
    }

    $(document).on("change", ".status-change", function() {
        let leadId = $(this).data("id");
        let newStatus = $(this).val();

        $.ajax({
            url: "/lead/update-status/" + leadId,
            type: "POST",
            data: { status: newStatus, _token: "{{ csrf_token() }}" },
            success: function() {
                alert("Status updated!");
                fetchUserLeads();
            }
        });
    });

    $("#prevPage").click(function() {
        if (currentPage > 1) {
            currentPage--;
            fetchUserLeads();
        }
    });

    $("#nextPage").click(function() {
        currentPage++;
        fetchUserLeads();
    });

    $("#search").on("keyup", function() {
        clearTimeout(typingTimer);
        typingTimer = setTimeout(fetchUserLeads, doneTypingInterval);
    });

    $(document).ready(function() {
        fetchUserLeads();
    });

    // Update Assigned User
    $(document).on("change", ".assign-user", function() {
        let leadId = $(this).data("id");
        let selectedUserId = $(this).val();
        
        if (!selectedUserId) {
            alert("Please select a user!");
            return;
        }

        if (!confirm("Are you sure you want to assign this lead?")) {
            return;
        }

        $.ajax({
            url: "/updateLeadAssignedUser",
            type: "POST",
            data: { lead_id: leadId, user_id: selectedUserId, _token: "{{ csrf_token() }}" },
            success: function(response) {
                alert("Lead assigned successfully!");
                fetchUserLeads();
            },
            error: function(xhr, status, error) {
                console.error("Error updating lead:", error);
                alert("Failed to assign user! Check console.");
            }
        });
    });

        $(document).on("click", ".view-details", function() {
        let lead = $(this).data("lead");

        $("#modalCreatedDate").text(new Date(lead.created_at).toLocaleString());
        $("#modalFullName").text(lead.full_name);
        $("#modalDOB").text(lead.date_of_birth);
        $("#modalPhone").text(lead.phone_number);
        $("#modalEmail").text(lead.email);
        $("#modalAddress").text(`${lead.street}, ${lead.city}, ${lead.state}`);
        $("#modalZipCode").text(lead.zip_code);

        $("#modalEmployerName").text(lead.employer_name);
        $("#modalEmploymentStatus").text(lead.employment_status);
        $("#modalJobTitle").text(lead.job_title);
        $("#modalEmploymentDuration").text(lead.employment_duration);

        $("#modalIncome").text(lead.monthly_income);
        $("#modalWorkPhone").text(lead.work_phone);
        $("#modalHousingStatus").text(lead.housing_status);
        $("#modalMonthlyPayment").text(lead.monthly_payment);
        $("#modalResidenceDuration").text(lead.residence_duration);
        $("#modalBankruptcyHistory").text(lead.bankruptcy_history);
        $("#modalCoSigner").text(lead.co_signer);
        $("#modalSSN").text(lead.social_security_number);

        $("#modalCreditCheck").text(lead.credit_check_consent);
        $("#modalVehicle").text(lead.vehicle_type);
        $("#modalPreference").text(lead.vehicle_preference);
        $("#modalStatus").text(lead.status.charAt(0).toUpperCase() + lead.status.slice(1).toLowerCase());


        $("#viewLeadModal").modal("show");
    });


</script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

</body>
</html>
